@@ -8,7 +8,7 @@ use warnings;
 # We intercept the debugging output and compare these.
 
 use Test::More;
-use Config;
+
 our $api;
 
 BEGIN {
@@ -16,11 +16,10 @@ BEGIN {
     use_ok("SVGPDF");
 }
 
-# For some specific build variants.
-my $var = $Config{uselongdouble} ? "-ld" : "";
-diag("Using variant $var") if $var;
 my $test = 2;
 
+return $test unless -f ".testall";
+
 BAIL_OUT("Missing test data") unless -d "regtest";
 
 # Setup PDF context.
@@ -48,7 +47,6 @@ foreach my $file ( sort @files ) {
     #diag("Testing: $file");
     ( my $out = $file ) =~ s/\.svg/.out/;
     ( my $ref = $file ) =~ s/\.svg/.ref/;
-    ( my $vref = $file ) =~ s/\.svg/$var.ref/;
 
     my $o;
 
@@ -61,14 +59,10 @@ foreach my $file ( sort @files ) {
     close(STDERR);
     open( STDERR, '>&', $errfd );
 
-    my $ok = $o && @$o;
-    ok( $ok, "Have XO results" );
+    ok( $o && @$o, "Have XO results" );
     $test++;
-    if ( $var && -s $vref ) {
-	$ref = $vref;
-	diag("Using ref = $ref");
-    }
-    $ok = -s $ref && !differ( $out, $ref );
+
+    my $ok = -s $ref && !differ( $out, $ref );
     ok( $ok, $file );
     $test++;
     unlink($out), next if $ok;
@@ -114,10 +108,8 @@ sub differ {
 
 my $font;
 sub fonthandlercallback {
-    my ( $self, %args ) = @_;
-    my $pdf   = $args{pdf};
-    my $style = $args{style};
-    my $key   = join("|", map { $_ // "normal" } @{$style}{qw(font-family font-style font-weight)});
+    my ( $self, $pdf, $style ) = @_;
+    my $key = join("|", map { $_ // "normal" } @{$style}{qw(font-family font-style font-weight)});
     $fccalls->{$key}++;
     $font //= $pdf->font('Times-Roman');
 }
